@@ -5,8 +5,10 @@ import pyarrow
 
 sys.path.insert(1, os.path.join(sys.path[0], ".."))
 
-from orso.dataframe import DataFrame
+
 from orso import converters
+from orso.dataframe import DataFrame
+from orso.types import OrsoTypes
 
 
 def test_from_arrow():
@@ -30,12 +32,12 @@ def test_from_arrow():
     tables = [table1, table2]
 
     # Test the function with a limit of 4 rows
-    rows, schema = converters.from_arrow(tables, 4)
+    rows, schema = converters.from_arrow(tables, 3)
     result = DataFrame(rows=rows, schema=schema)
 
     # Verify that the result has the correct number of rows and columns
-    assert len(result) == 4
-    assert len(result.column_names) == 3
+    assert len(result) == 3, len(result)
+    assert len(result.column_names) == 3, len(result.column_names)
 
     # Verify that the result has the correct column names and data types
     assert result.column_names == ("id", "name", "active")
@@ -53,13 +55,12 @@ def test_from_arrow_with_single_table():
 
     # Check that the instance has the correct rows and schema
     expected_rows = [("Alice", 25), ("Bob", 30), ("Charlie", 35)]
-    expected_schema = {
-        "name": {"type": str, "nullable": True},
-        "age": {"type": int, "nullable": True},
-    }
+    expected_columns = ["name", "age"]
+    expected_types = [OrsoTypes.VARCHAR, OrsoTypes.INTEGER]
     obj.materialize()
     assert obj._rows == expected_rows, obj._rows
-    assert obj._schema == expected_schema, obj._schema
+    assert [c.name for c in obj._schema.columns] == expected_columns
+    assert [c.type for c in obj._schema.columns] == expected_types
 
 
 def test_from_arrow_with_multiple_tables():
@@ -97,24 +98,49 @@ def test_from_arrow_with_multiple_tables():
         ("Ethan", 20),
         ("Olivia", 55),
     ]
-    expected_schema = {
-        "name": {"type": str, "nullable": True},
-        "age": {"type": int, "nullable": True},
-    }
+    expected_columns = ["name", "age"]
+    expected_types = [OrsoTypes.VARCHAR, OrsoTypes.INTEGER]
     obj.materialize()
     assert obj._rows == expected_rows, obj._rows
-    assert obj._schema == expected_schema
+    assert [c.name for c in obj._schema.columns] == expected_columns
+    assert [c.type for c in obj._schema.columns] == expected_types
 
 
 def test_from_arrow_none():
     rows, schema = converters.from_arrow(None)
-    assert rows == []
+    assert list(rows) == [], rows
     assert schema == {}
 
 
-if __name__ == "__main__":  # pragma: no cover
-    test_from_arrow()
-    test_from_arrow_with_single_table()
-    test_from_arrow_with_multiple_tables()
-    test_from_arrow_none()
-    print("✅ okay")
+def test_opteryx_arrow_small():
+    import opteryx
+    import orso
+
+    planets = opteryx.query("SELECT * FROM $planets")
+    planets_arrow = planets.arrow()
+    assert isinstance(planets_arrow, pyarrow.Table)
+    assert planets_arrow.shape == (9, 20)
+
+    planets2 = orso.DataFrame.from_arrow(planets_arrow)
+    assert isinstance(planets2, orso.DataFrame)
+    assert planets2.shape == (9, 20)
+
+
+def test_opteryx_arrow_medium():
+    import opteryx
+    import orso
+
+    fake = opteryx.query("SELECT * FROM FAKE(100000, 100) AS FK;")
+    fake_arrow = fake.arrow()
+    assert isinstance(fake_arrow, pyarrow.Table)
+    assert fake_arrow.shape == (100000, 100), fake_arrow.shape
+
+    fake2 = orso.DataFrame.from_arrow(fake_arrow)
+    assert isinstance(fake2, orso.DataFrame)
+    assert fake2.shape == (100000, 100)
+
+
+if __name__ == "__main__":  # prgama: nocover
+    from tests import run_tests
+
+    run_tests()
